"use strict";(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[3405],{33405:(e,a,r)=>{r.d(a,{diagram:()=>g});var t=r(93206),n=r(55209),s=r(51820),d=r(16990),i={parse:(0,s.K2)(async e=>{let a=await (0,d.qg)("info",e);s.Rm.debug(a)},"parse")},o={version:t.n.version+""},p=(0,s.K2)(()=>o.version,"getVersion"),g={parser:i,db:{getVersion:p},renderer:{draw:(0,s.K2)((e,a,r)=>{s.Rm.debug("rendering info diagram\n"+e);let t=(0,n.D)(a);(0,s.a$)(t,100,400,!0),t.append("g").append("text").attr("x",100).attr("y",40).attr("class","version").attr("font-size",32).style("text-anchor","middle").text(`v${r}`)},"draw")}}}}]);